# Issue Report Template

## Type of Report
Please select one:
- Bug Report
- Feature Request
- Documentation Issue
- Code of Conduct Violation
- Other (please specify)

## Description
Provide a clear and concise description of the issue:

* [ ] Brief summary
* [ ] Expected behavior
* [ ] Actual behavior
* [ ] Steps to reproduce (if applicable)

## Additional Information
Add any relevant details:
- Operating System: _____________________
- Python Version: _______________________
- Package Version: ______________________
- Error Messages: _______________________

## Supporting Materials
Attach or link to:
- Screenshots
- Log files
- Stack traces
- Code snippets
- Any other relevant documentation

## Priority Level
Select one:
- Critical (blocks all work)
- High (major impact)
- Medium (some impact)
- Low (minor issue)

## Labels
(Suggested labels for maintainers):
- bug
- enhancement
- docs
- coc-violation
- help-wanted
- good-first-issue
